﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace FlatDataSourceBasic.WPF.Data
{
    public class ProductData
    {
        [DisplayAttribute(Name = "Sales Regions")]
        public string Region
        {
            get;
            set;
        }

        [DisplayAttribute(AutoGenerateField = false)]
        public string Distributor
        {
            get;
            set;
        }

        [DisplayAttribute(Name = "Products")]
        public string ProductCategory
        {
            get;
            set;
        }

        [DisplayAttribute(AutoGenerateField = false)]
        public string Brand
        {
            get;
            set;
        }

        [Display(AutoGenerateField = false)]
        public string ProductName
        {
            get;
            set;
        }

        [DisplayFormat(DataFormatString = "{0:C2}")]
        [DisplayAttribute(Name = "Cost (Attribute)")]
        public double Cost
        {
            get;
            set;
        }
    }

    public static class ProductDataGenerator
    {
        private static string[] regions = new string[] { "Region1", "Region2", "Region3" };
        private static string[] distributors = new string[] { "Distributor1", "Distributor2", "Distributor3", "Distributor4", "Distributor5" };

        private static string[] categories = new string[] { "Category1", "Category2", "Category3" };
        private static string[] brands = new string[] { "Brand1", "Brand2", "Brand3", "Brand4", "Brand5", "Brand6" };
        private static string[] products = new string[] { "Product1", "Product2", "Product3", "Product4", "Product5", "Product6", "Product7", "Product8" };

        private static Random randomRegions = new Random();
        private static Random randomDistrbutors = new Random();
        private static Random randomCategories = new Random();
        private static Random randomBrands = new Random();
        private static Random randomProducts = new Random();
        private static Random randomCost = new Random();

        public static IEnumerable<ProductData> Generate()
        {            
            IList<ProductData> data = new List<ProductData>();
            for (int i = 0; i < 10000; i++)
            {
                string region = regions[randomRegions.Next(0, 3)];
                string distributor = distributors[randomDistrbutors.Next(0, 5)];
                string category = categories[randomCategories.Next(0, 2)];
                string brand = brands[randomBrands.Next(0, 5)];
                string product = products[randomProducts.Next(0, 7)];

                double cost = randomCost.NextDouble() * 1000;

                ProductData productData = new ProductData
                                              {
                                                  Brand = brand,
                                                  Distributor = distributor,
                                                  ProductCategory = category,
                                                  ProductName = product,
                                                  Region = region,
                                                  Cost = cost
                                              };

                data.Add(productData);
            }


            return data;
        }
    }
}
